@@ -21,6 +21,7 @@
 
 package Shell::GetEnv;
 
+require 5.008000;
 use strict;
 use warnings;
 
@@ -29,7 +30,7 @@ use Carp;
 use File::Temp;
 use Shell::GetEnv::Dumper;
 
-our $VERSION = '0.03_1';
+our $VERSION = '0.08_01';
 
 
 # a compendium of shells
@@ -41,6 +42,12 @@ my %shells = (
 		       Echo      => 'x',
 		      },
 
+	      dash => {
+		       Interactive     => 'i',
+		       Verbose   => 'v',
+		       Echo      => 'x',
+		      },
+
 	      sh => {
 		     Interactive     => 'i',
 		     Verbose   => 'v',
@@ -74,7 +81,7 @@ my %Opts = ( Startup => 1,
 	     Debug => 0,
 	     Echo    => 0,
 	     Verbose => 0,
-	     Interactive => 1,
+	     Interactive => 0,
 	     Redirect => 1,
 	     STDERR  => undef,
 	     STDOUT  => undef,
@@ -227,21 +234,30 @@ sub _shell_options
 
     my $shell = $shells{$self->{Shell}};
 
+    ## no critic (ProhibitAccessOfPrivateData)
+
     my @options = 
       map { $shell->{$_} }
 	grep { exists $shell->{$_} && $self->{$_} }
 	  qw( NoStartup Echo Verbose Interactive )
 	    ;
 
-    # bundled options are those without the leading hyphen
-    my @bundled = grep{ ! /^-/ } @options;
+    ## use critic
+
+
+    # bundled options are those without a leading hyphen or plus
+    my %options = map { ( $_ => 1 ) } @options;
+    my @bundled = grep{ ! /^[-+]/ } keys %options;
+    delete @options{@bundled};
+
     my $bundled = @bundled ? '-' . join( '', @bundled ) : undef;
 
     # long options; bash treats these differently
-    my @longopts = grep{ /^--/ } @options;
+    my @longopts = grep{ /^--/ } keys %options;
+    delete @options{@longopts};
 
     # everything else
-    my @otheropts = grep { /^-[^-]/ } @options;
+    my @otheropts = keys %options;
 
     $self->{ShellOptions} =
 			[ 
@@ -346,7 +362,7 @@ sub envs
     if ( $opt{DiffsOnly} )
     {
 	my @delkeys =
-	  grep { exists $ENV{$_} && $env{$_} ne $ENV{$_} } keys %env;
+	  grep { exists $ENV{$_} && $env{$_} eq $ENV{$_} } keys %env;
 
 	delete @env{@delkeys};
     }
@@ -517,7 +533,9 @@ B<STDOUT> attribute is used.  It defaults to I<false>.
 
 =item Interactive I<boolean>
 
-If true, put the shell in interactive mode.  It defaults to I<true>.
+If true, put the shell in interactive mode. Some shells do not react
+well when put in interactive mode but not connected to terminals.
+Try using the B<Expect> option instead. This defaults to I<false>.
 
 =item Redirect I<boolean>
 
